/**
 * Copyright (C) 2006 OQube 
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *  
 * author: Arnaud Bailly - abailly AT oqube DOT com
 * created: 14 juin 2006
 */
package speculoos.beans;

import java.util.Collection;


/**
 * Basic interface for various implementations of 
 * objects used to configuer a mapper.
 * This interface is a receptacle for storing field 
 * definitions associated with a map definition that
 * is later used for mapper configuration and generation.
 * 
 * @author nono
 *
 */
public interface MapStructure {

	/**
	 * 
	 * @return the list of fields defined in this mapper object. 
	 * @see MapEntry
	 */
	Collection /* < MapEntry > */ getFields();
	
	/**
	 * 
	 * @return the name of this structure.
	 */
	String getName();

	/**
	 * Return the list of all inherited fields in this structure.
	 * 
	 * @return a List<MapEntry> of fields definition.
	 */
	Collection getInheritedFields();
	
}
